@@ -45,8 +45,10 @@
 //! [`assert_markdown_deps_updated`]: macro.assert_markdown_deps_updated.html
 //! [`assert_html_root_url_updated`]: macro.assert_html_root_url_updated.html
 
-#![doc(html_root_url = "https://docs.rs/version-sync/0.3.0")]
+#![doc(html_root_url = "https://docs.rs/version-sync/0.3.1")]
+#![deny(missing_docs)]
 
+extern crate itertools;
 extern crate pulldown_cmark;
 extern crate semver_parser;
 extern crate syntex_syntax as syntax;
@@ -65,6 +67,7 @@ use semver_parser::version::parse as parse_version;
 use syntax::parse::{ParseSess, parse_crate_attrs_from_source_str};
 use toml::Value;
 use url::Url;
+use itertools::join;
 
 /// The common result type, our errors will be simple strings.
 type Result<T> = result::Result<T, String>;
@@ -109,10 +112,7 @@ fn read_file(path: &str) -> std::io::Result<String> {
 
 /// Indent every line in text by four spaces.
 fn indent(text: &str) -> String {
-    text.lines()
-        .map(|line| String::from("    ") + line)
-        .collect::<Vec<_>>()
-        .join("\n")
+    join(text.lines().map(|line| String::from("    ") + line), "\n")
 }
 
 /// Verify that the version range request matches the given version.
@@ -146,6 +146,11 @@ fn version_matches_request(version: &Version, request: &VersionReq) -> Result<()
                                        patch));
                 }
             }
+            if pred.pre != version.pre {
+                return Err(format!("expected pre-release {:?}, found {:?}",
+                                   join(&version.pre, "."),
+                                   join(&pred.pre, ".")));
+            }
         }
         _ => return Ok(()), // We cannot check other operators.
     }
@@ -604,6 +609,14 @@ mod tests {
             assert_eq!(version_matches_request(&version, &request),
                        Err(String::from("expected patch version 4, found 3")));
         }
+
+        #[test]
+        fn bad_pre_release() {
+            let version = parse_version("1.2.3-rc2").unwrap();
+            let request = parse_request("1.2.3-rc1").unwrap();
+            assert_eq!(version_matches_request(&version, &request),
+                       Err(String::from("expected pre-release \"rc2\", found \"rc1\"")));
+        }
     }
 
     mod test_extract_version_request {
